# CanvasDuplicates

A component that displays data duplicates based on a column prefixed `duplicates_`.
This column must contain lists of numbers that signal which duplicate group an item belongs to.

## Installation

```bash
pip install canvas_duplicates
```

## Usage

To learn how to use Canvas, see the [documentation](https://betterwithdata.github.io/ml-canvas/).

## Development

To learn about how to build Canvas from source and how to contribute to the framework, please look at [CONTRIBUTING.md](../CONTRIBUTING.md) and the [development documentation](https://betterwithdata.github.io/ml-canvas/contributing.html).
